#!/bin/bash

#shopt -s extglob


###################################################################
# Script para facilitar o uso dos parser gerados polo compilador compi-beta.
#   - - A varibel DEPPATTERN_DIR estabelece o PATH dos programas.
#   - - Cada tagger ten as sas propias variveis e configuraoes.
#
# Grupo de Gramtica do espaol 2008
###################################################################

############################
# Config
############################

DEPPATTERN_DIR="./DepPattern"
PROGS=$DEPPATTERN_DIR"/scripts"
DIRPARSER=$DEPPATTERN_DIR"/parsers"


############################
# Config de Freeling
############################

export FREELINGSHARE="/usr/share/FreeLing"
FREELING="/usr/bin/analyzer"
FREELING_OPTS="--noloc --noquant --nodate --flush"


############################
# Config de Treetagger
############################

TREETAGGER="./tree-tagger"

############################
# Functions
############################

help()
{
  echo "Syntax: dp.sh  <type_of_output> <tagger> <lang> <file> [parser] [grammar]
      
      type_of_output= -a (dependency analysis), -fa (full dependency analysis) -c (correct tagged text)
      tagger=freeling, treetagger
      language=gl, es, en, pt, fr
      file=path of the file input 
            parser=path of the parser, or name of the parser generated from grammar
            grammar=path of the file grammar
         
"
  exit
}


# Parmetros obrigatorios
[ $# -lt 4 ] && help
FLAG=$1
TAGGER=$2
LANG=$3
FILE=$4

# Parmetros opcionais
GRAMMAR=""
PARSER="user_parser" #por defeito
[ "$5" != "" ] && PARSER=$5
[ "$6" != "" ] && GRAMMAR=$6 


# Comprobacins
if [ "$TAGGER" != "freeling" ] &&  [ "$TAGGER" != "treetagger" ]; then
  help;
  echo "help" ;
fi

if [ "$FLAG" != "-a" ] &&  [ "$FLAG" != "-c" ] && [ "$FLAG" != "-fa" ] ; then
  help;
  echo "help" ;
fi

case $LANG in
  es) ;;
  en) ;;
  gl) ;;
  pt) ;;
  fr) ;;
  *) help
esac

#echo "$FLAG $TAGGER - $LANG - $FILE - $GRAMMAR - $PARSER"

##Lanar o Compi se houver gramtica
if [ "$GRAMMAR" != "" ]; then
        ruby compi-beta.rb $GRAMMAR $PARSER ;
        NAMEPARSER="./$PARSER"

#Lanar o parser especificado no caso de nao haver gramatica
elif [ "$GRAMMAR" == "" ] && [ "$PARSER" != "user_parser" ]; then
      NAMEPARSER="./$PARSER"
      NAMEPARSER=`echo $NAMEPARSER | sed "s/.perl$//"`
# Lanar o parser por defeito
else
     NAMEPARSER="$DIRPARSER/parserDefault-$LANG"
     NAMEPARSER=`echo $NAMEPARSER | sed "s/.perl$//"`
fi


#echo "$TAGGER - $LANG - $FILE - $GRAMMAR - $NAMEPARSER"
# Opcoes
if [ "$TAGGER" == "freeling" ]; then
  CMD="$FREELING $FREELING_OPTS -f $FREELINGSHARE/config/$LANG.cfg" ;
  FILTER="$PROGS/AdapterFreeling-${LANG}.perl"
else
  CMD="$TREETAGGER-$LANG" ;
  FILTER="$PROGS/AdapterTreetagger-${LANG}.perl"
fi

#echo $NAMEPARSER


#NAMEFILE=`basename $FILE`;

ZIP=`echo $FILE |awk '($0 ~ /(gz$|zip$)/) {print "zip"}'`


if [ "$ZIP" == "zip" ] ; then
 zcat $FILE | $CMD | $FILTER | $NAMEPARSER.perl $FLAG  ;
 
else 
  cat $FILE | $CMD | $FILTER | $NAMEPARSER.perl $FLAG  ;
fi
